==> apache-cxf-3.4.5-src.tar.gz: apache-cxf-3.4.5-src/rt/javascript/javascript-tests/src/test/java/org/apache/cxf/javascript/fortest/BeanRequestWrapper.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.javascript.fortest;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * Wrapper class.
 */
@XmlRootElement(namespace = "uri:org.apache.cxf.javascript.testns")
// specify alphabetical order explicitly to remind us that there is JavaScript code that knows this order!
@XmlType(namespace = "uri:org.apache.cxf.javascript.testns",
         propOrder = {"bean1", "beanArray" })
public class BeanRequestWrapper {
    private TestBean1 bean1;
    private TestBean1[] beanArray;

    public TestBean1 getBean1() {
        return bean1;
    }
    public void setBean1(TestBean1 bean1) {
        this.bean1 = bean1;
    }
    public TestBean1[] getBeanArray() {
        return beanArray;
    }
    public void setBeanArray(TestBean1[] beanArray) {
        this.beanArray = beanArray;
    }
}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/rt/javascript/javascript-tests/src/test/java/org/apache/cxf/javascript/fortest/BeanRequestWrapper.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.javascript.fortest;

import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;

/**
 * Wrapper class.
 */
@XmlRootElement(namespace = "uri:org.apache.cxf.javascript.testns")
// specify alphabetical order explicitly to remind us that there is JavaScript code that knows this order!
@XmlType(namespace = "uri:org.apache.cxf.javascript.testns",
         propOrder = {"bean1", "beanArray" })
public class BeanRequestWrapper {
    private TestBean1 bean1;
    private TestBean1[] beanArray;

    public TestBean1 getBean1() {
        return bean1;
    }
    public void setBean1(TestBean1 bean1) {
        this.bean1 = bean1;
    }
    public TestBean1[] getBeanArray() {
        return beanArray;
    }
    public void setBeanArray(TestBean1[] beanArray) {
        this.beanArray = beanArray;
    }
}
